@@ -7,13 +7,12 @@ use VCI::Util;
 
 extends 'VCI';
 
-our $VERSION = '0.3.1';
+our $VERSION = '0.4.0_1';
 
-has 'x_ua' => (is => 'ro', isa => 'LWP::UserAgent', lazy => 1,
-               default => sub { shift->build_x_ua });
+has 'x_ua' => (is => 'ro', isa => 'LWP::UserAgent', lazy_build => 1);
 has 'x_timeout' => (is => 'ro', isa => 'Int', default => sub { 60 });
 
-sub build_x_ua {
+sub _build_x_ua {
     my $self = shift;
     return LWP::UserAgent->new(
         agent => __PACKAGE__ . " $VERSION",
@@ -158,7 +157,7 @@ Max Kanat-Alexander <mkanat@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007 by Everything Solved, Inc.
+Copyright 2007-2008 by Everything Solved, Inc.
 
 L<http://www.everythingsolved.com>
 
